import * as apig from "@aws-cdk/aws-apigatewayv2-alpha";
import { Duration } from "./duration.js";
export interface CorsProps {
    /**
     * Specifies whether credentials are included in the CORS request.
     */
    allowCredentials?: boolean;
    /**
     * The collection of allowed headers.
     */
    allowHeaders?: string[];
    /**
     * The collection of allowed HTTP methods.
     */
    allowMethods?: (keyof typeof apig.CorsHttpMethod)[];
    /**
     * The collection of allowed origins.
     *
     * @example
     * ```js
     * // Allow all origins
     * allowOrigins: ["*"]
     *
     * // Allow specific origins. Note that the url protocol, ie. "https://", is required.
     * allowOrigins: ["https://domain.com"]
     * ```
     */
    allowOrigins?: string[];
    /**
     * The collection of exposed headers.
     */
    exposeHeaders?: string[];
    /**
     * Specify how long the results of a preflight response can be cached
     */
    maxAge?: Duration;
}
export declare function buildCorsConfig(cors?: boolean | CorsProps): apig.CorsPreflightOptions | undefined;
